@@ -1,4 +1,4 @@
-/* vim: set textwidth=80 tabstop=4: */
+/* vim: set textwidth=80 tabstop=4 */
 
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
@@ -60,8 +60,16 @@ struct _progress_widget {
 	guint		position;
 };
 
+typedef enum {
+    A_FILE_OK           = 1 << 0,
+    A_FILE_EXISTS       = 1 << 1,
+    A_FILE_IS_LINK      = 1 << 2,
+    A_FILE_IS_DIR       = 1 << 3,
+    A_FILE_NO_WRITE     = 1 << 4,
+    A_FILE_UNKNOWN      = 1 << 5
+} AFileTest;
+
 static progress_widget* progress = NULL;
-/*static gboolean cancelled = FALSE;*/
 
 static progress_widget* init_progress() {
 	progress_widget* ptr = malloc(sizeof(*ptr));
@@ -166,6 +174,9 @@ static struct ArchivePage* init_archive_page() {
 	page->md5sum = NULL;
 	page->rename = FALSE;
 	page->rename_files = NULL;
+        page->isoDate = NULL;
+        page->unlink_files = NULL;
+        page->unlink = FALSE;
 
 	return page;
 }
@@ -178,10 +189,6 @@ static void dispose_archive_page(struct ArchivePage* page) {
 	if (page->name)
 		g_free(page->name);
 	page->name = NULL;
-/*	if (page->compress_methods)
-		g_slist_free(page->compress_methods);
-	if (page->archive_formats)
-		g_slist_free(page->archive_formats);*/
 	g_free(page);
 }
 
@@ -226,10 +233,12 @@ static COMPRESS_METHOD get_compress_method(GSList* btn) {
 				debug_print("BZIP2 compression enabled\n");
 				return BZIP2;
 			}
-/*			else if (strcmp("COMPRESS", name) == 0) {
+#if NEW_ARCHIVE_API
+                        else if (strcmp("COMPRESS", name) == 0) {
 				debug_print("COMPRESS compression enabled\n");
 				return COMPRESS;
-			}*/
+			}
+#endif
 			else if (strcmp("NONE", name) == 0) {
 				debug_print("Compression disabled\n");
 				return NO_COMPRESS;
@@ -374,6 +383,8 @@ static void walk_folder(struct ArchivePage* page, FolderItem* item,
 	gchar* md5_file = NULL;
 	gchar* text = NULL;
 	gchar* file = NULL;
+        MsgTrash* msg_trash = NULL;
+        const gchar* date = NULL;
 
 	if (recursive && ! page->cancelled) {
 		debug_print("Scanning recursive\n");
@@ -389,21 +400,33 @@ static void walk_folder(struct ArchivePage* page, FolderItem* item,
 		}
 	}
 	if (! page->cancelled) {
+                date = gtk_entry_get_text(GTK_ENTRY(page->isoDate));
+                debug_print("cut-off date: %s\n", date);
 		count = 0;
 		page->files += item->total_msgs;
 		msglist = folder_item_get_msg_list(item);
+                msg_trash = new_msg_trash(item);
 		for (cur = msglist; cur && ! page->cancelled; cur = cur->next) {
 			msginfo = (MsgInfo *) cur->data;
 			debug_print("%s_%s_%s_%s\n",
 				msginfo->date, msginfo->to, msginfo->from, msginfo->subject);
-			page->total_size += msginfo->size;
 			file = folder_item_fetch_msg(item, msginfo->msgnum);
+                        if (date && strlen(date) > 0 && !before_date(msginfo->date_t, date)) {
+                            page->files--;
+                            continue;
+                        }
+			page->total_size += msginfo->size;
 			/*debug_print("Processing: %s\n", file);*/
 			if (file) {
+                                if (page->unlink) {
+                                    archive_add_msg_mark(msg_trash, msginfo);
+                                }
 				if (page->rename) {
 					file = descriptive_file_name(page, file, msginfo);
-					if (!file)
-						continue;
+					if (!file) {
+                                                /* Could not create a descriptive name */
+                                            file = folder_item_fetch_msg(item, msginfo->msgnum);
+                                        }
 				}
 				if (page->md5) {
 					md5_file = g_strdup_printf("%s.md5", file);
@@ -431,6 +454,30 @@ static void walk_folder(struct ArchivePage* page, FolderItem* item,
 	}
 }
 
+static AFileTest file_is_writeable(struct ArchivePage* page) {
+    int fd;
+
+    if (g_file_test(page->name, G_FILE_TEST_EXISTS) &&
+				! page->force_overwrite)
+        return A_FILE_EXISTS;
+    if (g_file_test(page->name, G_FILE_TEST_IS_SYMLINK))
+        return A_FILE_IS_LINK;
+    if (g_file_test(page->name, G_FILE_TEST_IS_DIR))
+        return A_FILE_IS_DIR;
+    if ((fd = open(page->name, O_WRONLY | O_CREAT, S_IRUSR | S_IWUSR)) == -1) {
+        switch (errno) {
+            case EACCES: return A_FILE_NO_WRITE;
+            case EEXIST: return A_FILE_OK;
+            default:     return A_FILE_UNKNOWN;
+        }
+    }
+    else {
+        close(fd);
+        claws_unlink(page->name);
+    }
+    return A_FILE_OK;
+}
+
 static gboolean archiver_save_files(struct ArchivePage* page) {
 	GtkWidget* dialog;
 	MainWindow* mainwin = mainwindow_get_mainwindow();
@@ -442,6 +489,8 @@ static gboolean archiver_save_files(struct ArchivePage* page) {
 	guint orig_file;
 	GSList* list = NULL;
 	const gchar* res = NULL;
+        AFileTest perm;
+        gchar* msg;
 
 	if (page->path == NULL || page->name == NULL) {
 		/* Test if page->file and page->folder has uncommitted information */
@@ -457,20 +506,51 @@ static gboolean archiver_save_files(struct ArchivePage* page) {
 			return FALSE;
 		}
 	}
-	if (g_file_test(page->name, G_FILE_TEST_EXISTS) &&
-				! page->force_overwrite) {
-		dialog = gtk_message_dialog_new(
+	if ((perm = file_is_writeable(page)) != A_FILE_OK) {
+            switch (perm) {
+                case A_FILE_EXISTS:
+                    msg = g_strdup_printf(_("%s: Exists. Continue anyway?"), page->name);
+                    break;
+                case A_FILE_IS_LINK:
+                    msg = g_strdup_printf(_("%s: Is a link. Cannot continue"), page->name);
+                    break;
+                 case A_FILE_IS_DIR:
+                     msg = g_strdup_printf(_("%s: Is a directory. Cannot continue"), page->name);
+                    break;
+                case A_FILE_NO_WRITE:
+                     msg = g_strdup_printf(_("%s: Missing permissions. Cannot continue"), page->name);
+                    break;
+                case A_FILE_UNKNOWN:
+                    msg = g_strdup_printf(_("%s: Unknown error. Cannot continue"), page->name);
+                    break;
+                default: break;
+            }
+            if (perm == A_FILE_EXISTS) {
+ 		dialog = gtk_message_dialog_new(
 			GTK_WINDOW(mainwin->window),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_WARNING,
 			GTK_BUTTONS_OK_CANCEL,
-			_("%s: Exists. Continue anyway?"),
-			page->name);
+			msg);
 		response = gtk_dialog_run(GTK_DIALOG (dialog));
 		gtk_widget_destroy(dialog);
+                g_free(msg);
 		if (response == GTK_RESPONSE_CANCEL) {
 			return FALSE;
 		}
+            }
+            else {
+ 		dialog = gtk_message_dialog_new(
+			GTK_WINDOW(mainwin->window),
+			GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_OK,
+			msg);
+		response = gtk_dialog_run(GTK_DIALOG (dialog));
+		gtk_widget_destroy(dialog);
+                g_free(msg);
+		return FALSE;
+            }
 	}
 	if (! valid_file_name(page->name)) {
 		dialog = gtk_message_dialog_new(
@@ -504,6 +584,8 @@ static gboolean archiver_save_files(struct ArchivePage* page) {
 	recursive = gtk_toggle_button_get_active(
 					GTK_TOGGLE_BUTTON(page->recursive));
 	page->md5 = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->md5sum));
+	page->unlink = gtk_toggle_button_get_active(
+			GTK_TOGGLE_BUTTON(page->unlink_files));
 	create_progress_dialog(page);
 	walk_folder(page, item, recursive);
 	if (page->cancelled)
@@ -544,6 +626,9 @@ static gboolean archiver_save_files(struct ArchivePage* page) {
 		archive_free_file_list(page->md5, page->rename);
 		return FALSE;
 	}
+        if (page->unlink) {
+            archive_free_archived_files();
+        }
 	return TRUE;
 }
 
@@ -590,10 +675,11 @@ static void show_result(struct ArchivePage* page) {
 		case BZIP2:
 			method = g_strdup("BZIP2");
 			break;
-/*		case COMPRESS:
-			if (archive_write_set_compression_gzip(arch) != ARCHIVE_OK)
-				return archive_error_string(arch);
-			break;*/
+#if NEW_ARCHIVE_API
+                case COMPRESS:
+			method = g_strdup("Compress");
+			break;
+#endif
 		case NO_COMPRESS:
 			method = g_strdup("No Compression");
 			break;
@@ -616,7 +702,7 @@ static void show_result(struct ArchivePage* page) {
 			format = g_strdup("NO FORMAT");
 	}
 
-	stat(page->name, &st);
+	g_stat(page->name, &st);
 	dialog = gtk_dialog_new_with_buttons(
 			_("Archive result"),
 			GTK_WINDOW(mainwin->window),
@@ -723,7 +809,25 @@ static void show_result(struct ArchivePage* page) {
 				STRING2, msg, -1);
 	g_free(msg);
 
-	gtk_window_set_default_size(GTK_WINDOW(dialog), 320, 260);
+	gtk_list_store_append(list, &iter);
+	msg = g_strdup_printf("%s", (page->unlink) ? _("Yes") : _("No"));
+	gtk_list_store_set(
+				list, &iter,
+				STRING1, _("Delete selected files"),
+				STRING2, msg, -1);
+	g_free(msg);
+        
+        msg = g_strdup(gtk_entry_get_text(GTK_ENTRY(page->isoDate)));
+        if (msg) {
+	    gtk_list_store_append(list, &iter);
+	    gtk_list_store_set(
+				list, &iter,
+				STRING1, _("Select mails before"),
+				STRING2, msg, -1);
+        }
+	g_free(msg);
+
+        gtk_window_set_default_size(GTK_WINDOW(dialog), 320, 260);
 
 	gtk_widget_show_all(dialog);
 }
@@ -864,13 +968,15 @@ void archiver_gtk_show() {
 	GtkWidget* file_select;
 	GtkWidget* zip_radio_btn;
 	GtkWidget* bzip_radio_btn;
-/*	GtkWidget* compress_radio_btn;*/
+#if NEW_ARCHIVE_API
+        GtkWidget* compress_radio_btn;
+#endif
 	GtkWidget* no_radio_btn;
 	GtkWidget* shar_radio_btn;
 	GtkWidget* pax_radio_btn;
 	GtkWidget* cpio_radio_btn;
 	GtkWidget* tar_radio_btn;
-	GtkTooltips* tooltips;
+	CLAWS_TIP_DECL();
 	struct ArchivePage* page;
 	MainWindow* mainwin = mainwindow_get_mainwindow();
 
@@ -879,8 +985,6 @@ void archiver_gtk_show() {
 
 	page = init_archive_page();
 
-	tooltips = gtk_tooltips_new();
-
 	dialog = gtk_dialog_new_with_buttons (
 				_("Create Archive"),
 				GTK_WINDOW(mainwin->window),
@@ -916,13 +1020,13 @@ void archiver_gtk_show() {
 	page->folder = gtk_entry_new();
 	gtk_widget_set_name(page->folder, "folder");
 	gtk_box_pack_start(GTK_BOX(hbox1), page->folder, TRUE, TRUE, 0);
-	gtk_tooltips_set_tip(tooltips, page->folder,
-			_("Folder which is the root of the archive"), NULL);
+	CLAWS_SET_TIP(page->folder,
+			_("Folder which is the root of the archive"));
 
 	folder_select = gtkut_get_browse_directory_btn(_("_Browse"));
 	gtk_box_pack_start(GTK_BOX(hbox1), folder_select, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, folder_select,
-			_("Click this button to select a folder which is to be root of the archive"), NULL);
+	CLAWS_SET_TIP(folder_select,
+			_("Click this button to select a folder which is to be root of the archive"));
 
 	hbox1 = gtk_hbox_new(FALSE, 4);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
@@ -934,12 +1038,12 @@ void archiver_gtk_show() {
 	page->file = gtk_entry_new();
 	gtk_widget_set_name(page->file, "file");
 	gtk_box_pack_start(GTK_BOX(hbox1), page->file, TRUE, TRUE, 0);
-	gtk_tooltips_set_tip(tooltips, page->file, _("Archive location and name"), NULL);
+	CLAWS_SET_TIP(page->file, _("Archive location and name"));
 
 	file_select = gtkut_get_browse_directory_btn(_("_Select"));
 	gtk_box_pack_start(GTK_BOX(hbox1), file_select, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, file_select,
-			_("Click this button to select a name and location for the archive"), NULL);
+	CLAWS_SET_TIP(file_select,
+			_("Click this button to select a name and location for the archive"));
 
 	frame = gtk_frame_new(_("Choose compression"));
 	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_OUT);
@@ -953,29 +1057,31 @@ void archiver_gtk_show() {
 	zip_radio_btn = gtk_radio_button_new_with_mnemonic(NULL, "_ZIP");
 	gtk_widget_set_name(zip_radio_btn, "ZIP");
 	gtk_box_pack_start(GTK_BOX(hbox1), zip_radio_btn, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, zip_radio_btn,
-			_("Choose this option to use ZIP compression for the archive"), NULL);
+	CLAWS_SET_TIP(zip_radio_btn,
+			_("Choose this option to use ZIP compression for the archive"));
 
 	bzip_radio_btn = gtk_radio_button_new_with_mnemonic_from_widget(
 					GTK_RADIO_BUTTON(zip_radio_btn), "BZIP_2");
 	gtk_widget_set_name(bzip_radio_btn, "BZIP");
 	gtk_box_pack_start(GTK_BOX(hbox1), bzip_radio_btn, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, bzip_radio_btn,
-			_("Choose this option to use BZIP2 compression for the archive"), NULL);
-/*
+	CLAWS_SET_TIP(bzip_radio_btn,
+			_("Choose this option to use BZIP2 compression for the archive"));
+
+#if NEW_ARCHIVE_API
 	compress_radio_btn = gtk_radio_button_new_with_mnemonic_from_widget(
 					GTK_RADIO_BUTTON(zip_radio_btn), "C_ompress");
 	gtk_widget_set_name(compress_radio_btn, "COMPRESS");
 	gtk_box_pack_start(GTK_BOX(hbox1), compress_radio_btn, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, compress_radio_btn,
-		_("Choose this to use Compress compression for your archive"), NULL);
-*/
+	CLAWS_SET_TIP(compress_radio_btn,
+		_("Choose this to use Compress compression for your archive"));
+#endif
+
 	no_radio_btn = gtk_radio_button_new_with_mnemonic_from_widget(
 					GTK_RADIO_BUTTON(zip_radio_btn), _("_None"));
 	gtk_widget_set_name(no_radio_btn, "NONE");
 	gtk_box_pack_start(GTK_BOX(hbox1), no_radio_btn, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, no_radio_btn,
-		_("Choose this option to disable compression for the archive"), NULL);
+	CLAWS_SET_TIP(no_radio_btn,
+		_("Choose this option to disable compression for the archive"));
 
 	page->compress_methods = 
 			gtk_radio_button_get_group(GTK_RADIO_BUTTON(zip_radio_btn));
@@ -987,6 +1093,11 @@ void archiver_gtk_show() {
 	case COMPRESSION_BZIP:
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bzip_radio_btn), TRUE);
 		break;
+#if NEW_ARCHIVE_API
+        case COMPRESSION_COMPRESS:
+                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(compress_radio_btn), TRUE);
+                break;
+#endif
 	case COMPRESSION_NONE:
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(no_radio_btn), TRUE);
 		break;
@@ -1004,29 +1115,29 @@ void archiver_gtk_show() {
 	tar_radio_btn = gtk_radio_button_new_with_mnemonic(NULL, "_TAR");
 	gtk_widget_set_name(tar_radio_btn, "TAR");
 	gtk_box_pack_start(GTK_BOX(hbox1), tar_radio_btn, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, tar_radio_btn,
-			_("Choose this option to use TAR as format for the archive"), NULL);
+	CLAWS_SET_TIP(tar_radio_btn,
+			_("Choose this option to use TAR as format for the archive"));
 
 	shar_radio_btn = gtk_radio_button_new_with_mnemonic_from_widget(
 					GTK_RADIO_BUTTON(tar_radio_btn), "S_HAR");
 	gtk_widget_set_name(shar_radio_btn, "SHAR");
 	gtk_box_pack_start(GTK_BOX(hbox1), shar_radio_btn, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, shar_radio_btn,
-			_("Choose this to use SHAR as format for the archive"), NULL);
+	CLAWS_SET_TIP(shar_radio_btn,
+			_("Choose this to use SHAR as format for the archive"));
 
 	cpio_radio_btn = gtk_radio_button_new_with_mnemonic_from_widget(
 					GTK_RADIO_BUTTON(tar_radio_btn), "CP_IO");
 	gtk_widget_set_name(cpio_radio_btn, "CPIO");
 	gtk_box_pack_start(GTK_BOX(hbox1), cpio_radio_btn, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, cpio_radio_btn,
-		_("Choose this option to use CPIO as format for the archive"), NULL);
+	CLAWS_SET_TIP(cpio_radio_btn,
+		_("Choose this option to use CPIO as format for the archive"));
 
 	pax_radio_btn = gtk_radio_button_new_with_mnemonic_from_widget(
 					GTK_RADIO_BUTTON(tar_radio_btn), "PA_X");
 	gtk_widget_set_name(pax_radio_btn, "PAX");
 	gtk_box_pack_start(GTK_BOX(hbox1), pax_radio_btn, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, pax_radio_btn,
-		_("Choose this option to use PAX as format for the archive"), NULL);
+	CLAWS_SET_TIP(pax_radio_btn,
+		_("Choose this option to use PAX as format for the archive"));
 
 	page->archive_formats = 
 			gtk_radio_button_get_group(GTK_RADIO_BUTTON(tar_radio_btn));
@@ -1058,26 +1169,53 @@ void archiver_gtk_show() {
 	page->recursive = gtk_check_button_new_with_mnemonic(_("_Recursive"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->recursive), archiver_prefs.recursive);
 	gtk_box_pack_start(GTK_BOX(hbox1), page->recursive, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, page->recursive,
-		_("Choose this option to include subfolders in the archive"), NULL);
+	CLAWS_SET_TIP(page->recursive,
+		_("Choose this option to include subfolders in the archive"));
 	
 	page->md5sum = gtk_check_button_new_with_mnemonic(_("_MD5sum"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->md5sum), archiver_prefs.md5sum);
 	gtk_box_pack_start(GTK_BOX(hbox1), page->md5sum, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, page->md5sum,
+	CLAWS_SET_TIP(page->md5sum,
 		_("Choose this option to add MD5 checksums for each file in the archive.\n"
 		  "Be aware though, that this dramatically increases the time it\n"
-		  "will take to create the archive"), NULL);
+		  "will take to create the archive"));
 
 	page->rename_files = gtk_check_button_new_with_mnemonic(_("R_ename"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->rename_files), archiver_prefs.rename);
 	gtk_box_pack_start(GTK_BOX(hbox1), page->rename_files, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, page->rename_files,
+	CLAWS_SET_TIP(page->rename_files,
 		_("Choose this option to use descriptive names for each file in the archive.\n"
 		  "The naming scheme: date_from@to@subject.\n"
-		  "Names will be truncated to max 96 characters"), NULL);
+		  "Names will be truncated to max 96 characters"));
 
-	g_signal_connect(G_OBJECT(folder_select), "clicked", 
+        page->unlink_files = gtk_check_button_new_with_mnemonic(_("_Delete"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->unlink_files), archiver_prefs.unlink);
+	gtk_box_pack_start(GTK_BOX(hbox1), page->unlink_files, FALSE, FALSE, 0);
+	CLAWS_SET_TIP(page->unlink_files,
+		_("Choose this option to delete mails after archiving\n"
+                  "At this point only handles IMAP4, Local mbox and POP3"));
+
+
+	frame = gtk_frame_new(_("Selection options"));
+	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_OUT);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 4);
+	gtk_box_pack_start(GTK_BOX(vbox1), frame, FALSE, FALSE, 0);
+
+	hbox1 = gtk_hbox_new(FALSE, 4);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox1), 4);
+	gtk_container_add(GTK_CONTAINER(frame), hbox1);
+
+	file_label = gtk_label_new(_("Select mails before"));
+	gtk_box_pack_start(GTK_BOX(hbox1), file_label, FALSE, FALSE, 0);
+	
+	page->isoDate = gtk_entry_new();
+	gtk_widget_set_name(page->isoDate, "isoDate");
+	gtk_box_pack_start(GTK_BOX(hbox1), page->isoDate, TRUE, TRUE, 0);
+	CLAWS_SET_TIP(page->isoDate, 
+                _("Select emails before a certain date\n"
+                  "Date must comply to ISO-8601 [YYYY-MM-DD]"));
+
+        g_signal_connect(G_OBJECT(folder_select), "clicked", 
 			 G_CALLBACK(foldersel_cb), page);
 	g_signal_connect(G_OBJECT(file_select), "clicked",
 			 G_CALLBACK(filesel_cb), page);
