@@ -29,6 +29,9 @@
 #include "notification_lcdproc.h"
 #include "notification_trayicon.h"
 
+#ifdef HAVE_LIBCANBERRA_GTK
+# include <canberra-gtk.h>
+#endif
 
 typedef struct {
   GSList *collected_msgs;
@@ -45,6 +48,10 @@ static gboolean notification_traverse_hash_startup(GNode*, gpointer);
 static GHashTable *msg_count_hash;
 static NotificationMsgCount msg_count;
 
+#ifdef HAVE_LIBCANBERRA_GTK
+static gboolean canberra_new_email_is_playing = FALSE;
+#endif
+
 static void msg_count_hash_update_func(FolderItem*, gpointer);
 static void msg_count_update_from_hash(gpointer, gpointer, gpointer);
 static void msg_count_clear(NotificationMsgCount*);
@@ -90,6 +97,7 @@ void notification_update_msg_counts(FolderItem *removed_item)
 #ifdef NOTIFICATION_TRAYICON
   notification_update_trayicon();
 #endif
+  notification_update_urgency_hint();
 }
 
 static void msg_count_clear(NotificationMsgCount *count)
@@ -227,11 +235,11 @@ gboolean notification_notified_hash_msginfo_update(MsgInfoUpdate *msg_update)
       debug_print("Notification Plugin: Message has no message ID!\n");
       msgid = "";
     }
-    
+
     g_return_val_if_fail(msg != NULL, FALSE);
 
     if(g_hash_table_lookup(notified_hash, msgid) != NULL) {
-      
+
       debug_print("Notification Plugin: Removing message id %s from hash "
 		  "table\n", msgid);
       g_hash_table_remove(notified_hash, msgid);
@@ -256,7 +264,7 @@ void notification_notified_hash_startup_init(void)
   folder_list = folder_get_list();
   for(walk = folder_list; walk != NULL; walk = g_list_next(walk)) {
     folder = walk->data;
-    
+
     g_node_traverse(folder->node, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 		    notification_traverse_hash_startup, NULL);
   }
@@ -274,7 +282,7 @@ static gboolean notification_traverse_hash_startup(GNode *node, gpointer data)
 
   new_msgs_left = item->new_msgs;
   msg_list = folder_item_get_msg_list(item);
-  
+
   for(walk = msg_list; walk; walk = g_slist_next(walk)) {
     MsgInfo *msg = (MsgInfo*) walk->data;
     if(MSG_IS_NEW(msg->flags)) {
@@ -326,7 +334,7 @@ void notification_new_unnotified_msgs(FolderItemUpdateData *update_data)
   for(walk = msg_list; walk; walk = g_slist_next(walk)) {
     MsgInfo *msg;
     msg = (MsgInfo*) walk->data;
-    
+
     if(MSG_IS_NEW(msg->flags)) {
       gchar *msgid;
 
@@ -347,16 +355,23 @@ void notification_new_unnotified_msgs(FolderItemUpdateData *update_data)
 	g_hash_table_insert(notified_hash, g_strdup(msgid),
 			    GINT_TO_POINTER(1));
 	debug_print("no, added to table.\n");
-	
+
 	/* Do the notification */
 	notification_new_unnotified_do_msg(msg);
       }
-      
+
     } /* msg is 'new' */
   } /* for all messages */
   procmsg_msg_list_free(msg_list);
 }
 
+#ifdef HAVE_LIBCANBERRA_GTK
+static void canberra_finished_cb(ca_context *c, uint32_t id, int error, void *data)
+{
+  canberra_new_email_is_playing = FALSE;
+}
+#endif
+
 static void notification_new_unnotified_do_msg(MsgInfo *msg)
 {
 #ifdef NOTIFICATION_POPUP
@@ -368,6 +383,20 @@ static void notification_new_unnotified_do_msg(MsgInfo *msg)
 #ifdef NOTIFICATION_TRAYICON
   notification_trayicon_msg(msg);
 #endif
+
+#ifdef HAVE_LIBCANBERRA_GTK
+  /* canberra */
+  if(notify_config.canberra_play_sounds && !canberra_new_email_is_playing) {
+    MainWindow *mainwin;
+    ca_proplist *proplist;
+    mainwin = mainwindow_get_mainwindow();
+    ca_proplist_create(&proplist);
+    ca_proplist_sets(proplist,CA_PROP_EVENT_ID ,"message-new-email");
+    canberra_new_email_is_playing = TRUE;
+    ca_context_play_full(ca_gtk_context_get(), 0, proplist, canberra_finished_cb, NULL);
+    ca_proplist_destroy(proplist);
+  }
+#endif
 }
 
 /* If folders is not NULL, then consider only those folder items
@@ -389,7 +418,7 @@ GSList* notification_collect_msgs(gboolean unread_also, GSList *folder_items,
   folder_list = folder_get_list();
   for(walk = folder_list; walk != NULL; walk = g_list_next(walk)) {
     folder = walk->data;
-    
+
     g_node_traverse(folder->node, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 		    notification_traverse_collect, &collect_data);
   }
@@ -403,11 +432,12 @@ void notification_collected_msgs_free(GSList *collected_msgs)
     for(walk = collected_msgs; walk != NULL; walk = g_slist_next(walk)) {
       CollectedMsg *msg = walk->data;
       if(msg->from)
-	g_free(msg->from);
+				g_free(msg->from);
       if(msg->subject)
-	g_free(msg->subject);
+				g_free(msg->subject);
       if(msg->folderitem_name)
-	g_free(msg->folderitem_name);
+				g_free(msg->folderitem_name);
+			msg->msginfo = NULL;
       g_free(msg);
     }
     g_slist_free(collected_msgs);
@@ -460,16 +490,20 @@ static gboolean notification_traverse_collect(GNode *node, gpointer data)
 	return FALSE;
 
       if(MSG_IS_NEW(msg_info->flags) ||
-	 (MSG_IS_UNREAD(msg_info->flags) && cdata->unread_also)) {
-	cmsg = g_new(CollectedMsg, 1);
-	cmsg->from = g_strdup(msg_info->from ? msg_info->from : "");
-	cmsg->subject = g_strdup(msg_info->subject ? msg_info->subject : "");
-	if(msg_info->folder && msg_info->folder->name)
-	  cmsg->folderitem_name = g_strdup(msg_info->folder->path);
-	else
-	  cmsg->folderitem_name = g_strdup("");
-	cdata->collected_msgs = g_slist_prepend(cdata->collected_msgs, cmsg);
-	cdata->num_msgs++;
+				 (MSG_IS_UNREAD(msg_info->flags) && cdata->unread_also)) {
+
+				cmsg = g_new(CollectedMsg, 1);
+				cmsg->from = g_strdup(msg_info->from ? msg_info->from : "");
+				cmsg->subject = g_strdup(msg_info->subject ? msg_info->subject : "");
+				if(msg_info->folder && msg_info->folder->name)
+					cmsg->folderitem_name = g_strdup(msg_info->folder->path);
+				else
+					cmsg->folderitem_name = g_strdup("");
+
+				cmsg->msginfo = msg_info;
+
+				cdata->collected_msgs = g_slist_prepend(cdata->collected_msgs, cmsg);
+				cdata->num_msgs++;
       }
     }
     procmsg_msg_list_free(msg_list);
@@ -516,6 +550,27 @@ gboolean notify_include_folder_type(FolderType ftype, gchar *uistr)
   return retval;
 }
 
+static void fix_folderview_scroll(MainWindow *mainwin)
+{
+	static gboolean fix_done = FALSE;
+
+	if (fix_done)
+		return;
+
+	gtk_widget_queue_resize(mainwin->folderview->ctree);
+
+	fix_done = TRUE;
+}
+
+void notification_show_mainwindow(MainWindow *mainwin)
+{
+      gtk_window_deiconify(GTK_WINDOW(mainwin->window));
+      gtk_window_set_skip_taskbar_hint(GTK_WINDOW(mainwin->window), FALSE);
+      main_window_show(mainwin);
+      gtk_window_present(GTK_WINDOW(mainwin->window));
+      fix_folderview_scroll(mainwin);
+}
+
 #ifdef HAVE_LIBNOTIFY
 #define STR_MAX_LEN 511
 /* Returns a newly allocated string which needs to be freed */
