@@ -46,6 +46,11 @@ typedef struct
 	GtkWidget *include_news;
 	GtkWidget *include_rss;
 	GtkWidget *include_calendar;
+	GtkWidget *urgency_hint_new;
+	GtkWidget *urgency_hint_unread;
+#ifdef HAVE_LIBCANBERRA_GTK
+	GtkWidget *canberra_play_sounds;
+#endif
 } NotifyPage;
 
 NotifyPrefs notify_config;
@@ -148,6 +153,15 @@ PrefParam
 						NULL, NULL },
 				{ "include_calendar", "TRUE", &notify_config.include_calendar, P_BOOL,
 						NULL, NULL, NULL },
+				{ "urgency_hint_new", "FALSE", &notify_config.urgency_hint_new, P_BOOL,
+						NULL, NULL, NULL },
+				{ "urgency_hint_unread", "FALSE", &notify_config.urgency_hint_unread, P_BOOL,
+						NULL, NULL, NULL },
+
+#ifdef HAVE_LIBCANBERRA_GTK
+                { "canberra_play_sounds", "TRUE", &notify_config.canberra_play_sounds, P_BOOL,
+                        NULL, NULL, NULL },
+#endif
 
 #ifdef NOTIFICATION_BANNER
 				{	"banner_show", "0", &notify_config.banner_show, P_INT, NULL, NULL, NULL},
@@ -221,8 +235,13 @@ PrefParam
 #endif
 
 #ifdef NOTIFICATION_TRAYICON
+#ifndef G_OS_WIN32
 				{	"trayicon_enabled", "FALSE", &notify_config.trayicon_enabled, P_BOOL,
 					NULL, NULL, NULL},
+#else
+				{	"trayicon_enabled", "TRUE", &notify_config.trayicon_enabled, P_BOOL,
+					NULL, NULL, NULL},
+#endif
 				{	"trayicon_hide_at_startup", "FALSE",
 					&notify_config.trayicon_hide_at_startup, P_BOOL, NULL, NULL, NULL},
 				{	"trayicon_close_to_tray", "FALSE",
@@ -504,7 +523,7 @@ static void notify_create_prefs_page(PrefsPage *page, GtkWindow *window,
 	/* Include calendar folders */
 	checkbox = gtk_check_button_new_with_label(_("Calendar folders"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox),
-	notify_config.include_calendar);
+			notify_config.include_calendar);
 	gtk_box_pack_start(GTK_BOX(vbox), checkbox, FALSE, FALSE, 0);
 	gtk_widget_show(checkbox);
 	notify_page.include_calendar = checkbox;
@@ -516,9 +535,53 @@ static void notify_create_prefs_page(PrefsPage *page, GtkWindow *window,
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	/* Done. */
+	/* done with the frame */
 	gtk_widget_show(frame);
 	gtk_widget_show(vbox);
+
+	/* Frame */
+	frame = gtk_frame_new(_("Global notification settings"));
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 10);
+	gtk_box_pack_start(GTK_BOX(pvbox), frame, FALSE, FALSE, 0);
+
+	/* Frame vbox */
+	vbox = gtk_vbox_new(FALSE, 4);
+	gtk_container_add(GTK_CONTAINER(frame), vbox);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 8);
+
+	/* urgency hint new */
+	checkbox = gtk_check_button_new_with_label(_("Set window manager "
+			"urgency hint when new messages exist"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox),
+			notify_config.urgency_hint_new);
+	gtk_box_pack_start(GTK_BOX(vbox), checkbox, FALSE, FALSE, 0);
+	gtk_widget_show(checkbox);
+	notify_page.urgency_hint_new = checkbox;
+
+	/* urgency hint new */
+	checkbox = gtk_check_button_new_with_label(_("Set window manager "
+			"urgency hint when unread messages exist"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox),
+			notify_config.urgency_hint_unread);
+	gtk_box_pack_start(GTK_BOX(vbox), checkbox, FALSE, FALSE, 0);
+	gtk_widget_show(checkbox);
+	notify_page.urgency_hint_unread = checkbox;
+
+#ifdef HAVE_LIBCANBERRA_GTK
+	/* canberra */
+    checkbox = gtk_check_button_new_with_label(_("Use sound theme"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbox),
+            notify_config.canberra_play_sounds);
+    gtk_box_pack_start(GTK_BOX(vbox), checkbox, FALSE, FALSE, 0);
+    gtk_widget_show(checkbox);
+    notify_page.canberra_play_sounds = checkbox;
+#endif
+
+	/* done with the frame */
+	gtk_widget_show(frame);
+	gtk_widget_show(vbox);
+
+	/* done with the page */
 	gtk_widget_show(pvbox);
 	page->widget = pvbox;
 }
@@ -533,9 +596,14 @@ static void notify_save_prefs(PrefsPage *page)
 	notify_config.include_news =gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(notify_page.include_news));
 	notify_config.include_rss =gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(notify_page.include_rss));
 	notify_config.include_calendar
-			=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(notify_page.include_calendar));
+			= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(notify_page.include_calendar));
+	notify_config.urgency_hint_new = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(notify_page.urgency_hint_new));
+	notify_config.urgency_hint_unread = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(notify_page.urgency_hint_unread));
+#ifdef HAVE_LIBCANBERRA_GTK
+   notify_config.canberra_play_sounds = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(notify_page.canberra_play_sounds));
+#endif
 
-	notification_core_global_includes_changed();
+   notification_core_global_includes_changed();
 }
 
 #ifdef NOTIFICATION_BANNER
