@@ -47,14 +47,14 @@ static void notification_trayicon_on_popup_menu(GtkStatusIcon*,guint,
 static gboolean notification_trayicon_on_size_changed(GtkStatusIcon*,
 						      gint, gpointer);
 
-static void trayicon_get_all_cb(gpointer, guint, GtkWidget*);
-static void trayicon_compose_cb(gpointer, guint, GtkWidget*);
+static void trayicon_get_all_cb(GtkAction*, gpointer);
+static void trayicon_compose_cb(GtkAction*, gpointer);
 static void trayicon_compose_acc_cb(GtkMenuItem*, gpointer);
-static void trayicon_addressbook_cb(gpointer, guint, GtkWidget*);
-static void trayicon_exit_cb(gpointer, guint, GtkWidget*);
-static void trayicon_toggle_offline_cb(gpointer, guint, GtkWidget*);
+static void trayicon_addressbook_cb(GtkAction*, gpointer);
+static void trayicon_exit_cb(GtkAction*,gpointer);
+static void trayicon_toggle_offline_cb(GtkAction*,gpointer);
 #ifdef HAVE_LIBNOTIFY
-static void trayicon_toggle_notify_cb(gpointer, guint, GtkWidget*);
+static void trayicon_toggle_notify_cb(GtkAction*,gpointer);
 #endif
 
 #ifdef HAVE_LIBNOTIFY
@@ -67,7 +67,6 @@ typedef struct {
   gint num_calendar;
   gint num_rss;
   gchar *msg_path;
-  guint timeout_id;
   NotifyNotification *notification;
   GError *error;
 } NotificationTrayiconPopup;
@@ -78,7 +77,7 @@ static gboolean notification_trayicon_popup_add_msg(MsgInfo*,
 						    NotificationFolderType);
 static gboolean notification_trayicon_popup_create(MsgInfo*,
 						   NotificationFolderType);
-static gboolean popup_timeout_fun(gpointer);
+static void popup_timeout_fun(NotifyNotification*, gpointer);
 static void notification_trayicon_popup_free_func(gpointer);
 static void notification_trayicon_popup_default_action_cb(NotifyNotification*,
 							  const char*,void*);
@@ -93,22 +92,23 @@ G_LOCK_DEFINE_STATIC(trayicon_popup);
 static GtkStatusIcon *trayicon;
 static gboolean updating_menu = FALSE;
 static GtkWidget *traymenu_popup;
-static GtkItemFactory *traymenu_factory;
 
-static GtkItemFactoryEntry trayicon_popup_menu_entries[] = {
-  {N_("/_Get Mail"),	      NULL,trayicon_get_all_cb,	      0, NULL},
-  {"/---",		      NULL,NULL,		      0, "<Separator>"},
-  {N_("/_Email"),	      NULL,trayicon_compose_cb,	      0, NULL},
-  {N_("/_Email from account"),NULL,NULL,		      0, "<Branch>"},
-  {"/---",		      NULL,NULL,		      0, "<Separator>"},
-  {N_("/Open A_ddressbook"),  NULL,trayicon_addressbook_cb,   0, NULL},
-  {"/---",		      NULL,NULL,		      0, "<Separator>"},
+static GtkActionEntry trayicon_popup_menu_entries[] = {
+	{"SysTrayiconPopup", NULL, "SysTrayiconPopup" },
+	{"SysTrayiconPopup/GetMail", NULL, N_("_Get Mail"), NULL, NULL, G_CALLBACK(trayicon_get_all_cb) },
+	{"SysTrayiconPopup/---", NULL, "---" },
+	{"SysTrayiconPopup/Email", NULL, N_("_Email"), NULL, NULL, G_CALLBACK(trayicon_compose_cb) },
+	{"SysTrayiconPopup/EmailAcc", NULL, N_("E_mail from account"), NULL, NULL, NULL },
+	{"SysTrayiconPopup/OpenAB", NULL, N_("Open A_ddressbook"), NULL, NULL, G_CALLBACK(trayicon_addressbook_cb) },
+	{"SysTrayiconPopup/Exit", NULL, N_("E_xit Claws Mail"), NULL, NULL, G_CALLBACK(trayicon_exit_cb) },
+};
+
+static GtkToggleActionEntry trayicon_popup_toggle_menu_entries[] =
+{
+	{"SysTrayiconPopup/ToggleOffline",		NULL, N_("_Work Offline"), NULL, NULL, G_CALLBACK(trayicon_toggle_offline_cb) },
 #ifdef HAVE_LIBNOTIFY
-  {N_("/Show Trayicon Notifications"), NULL,trayicon_toggle_notify_cb, 0, "<CheckItem>"},
+	{"SysTrayiconPopup/ShowBubbles", NULL, N_("Show Trayicon Notifications"), NULL, NULL, G_CALLBACK(trayicon_toggle_notify_cb) },
 #endif
-  {N_("/_Work Offline"),      NULL,trayicon_toggle_offline_cb,0, "<CheckItem>"},
-  {"/---",		      NULL,NULL,		      0, "<Separator>"},
-  {N_("/E_xit Claws Mail"),   NULL,trayicon_exit_cb,	      0, "<StockItem>", GTK_STOCK_QUIT}
 };
 
 
@@ -147,7 +147,7 @@ void notification_trayicon_msg(MsgInfo *msginfo)
     for(; (list != NULL) && !found; list = g_slist_next(list)) {
       gchar *list_identifier;
       FolderItem *list_item = (FolderItem*) list->data;
-      
+
       list_identifier = folder_item_get_identifier(list_item);
       if(!strcmp2(list_identifier, identifier))
 	found = TRUE;
@@ -155,11 +155,11 @@ void notification_trayicon_msg(MsgInfo *msginfo)
       g_free(list_identifier);
     }
     g_free(identifier);
-    
+
     if(!found)
       return;
   } /* folder specific */
-  
+
   ftype = msginfo->folder->folder->klass->type;
 
   G_LOCK(trayicon_popup);
@@ -187,7 +187,7 @@ void notification_trayicon_msg(MsgInfo *msginfo)
       debug_print("Notification Plugin: Unknown folder type %d\n",ftype);
       G_UNLOCK(trayicon_popup);
       return;
-    } 
+    }
     break;
   default:
     debug_print("Notification Plugin: Unknown folder type %d\n",ftype);
@@ -195,13 +195,8 @@ void notification_trayicon_msg(MsgInfo *msginfo)
     return;
   }
 
-  
-  if(notification_trayicon_popup_add_msg(msginfo, nftype)) {
-    if(popup.timeout_id)
-      g_source_remove(popup.timeout_id);
-    popup.timeout_id = g_timeout_add(notify_config.trayicon_popup_timeout,
-				     popup_timeout_fun, NULL);
-  }
+
+  notification_trayicon_popup_add_msg(msginfo, nftype);
 
   G_UNLOCK(trayicon_popup);
 
@@ -237,7 +232,7 @@ void notification_update_trayicon()
   }
   else
     list = NULL;
-    
+
   notification_core_get_msg_count(list, &count);
 
   if(!trayicon) {
@@ -252,11 +247,15 @@ void notification_update_trayicon()
   buf = g_strdup_printf(_("New %d, Unread: %d, Total: %d"),
 			count.new_msgs, count.unread_msgs,
 			count.total_msgs);
+#if GTK_CHECK_VERSION(2,16,0)
+  gtk_status_icon_set_tooltip_text(trayicon, buf);
+#else
   gtk_status_icon_set_tooltip(trayicon, buf);
+#endif
   g_free(buf);
 
   /* Pixmap */
-  (prefs_common.work_offline) ? (offset = 1) : (offset = 0);
+  (prefs_common_get_prefs()->work_offline) ? (offset = 1) : (offset = 0);
 
   if((count.new_msgs > 0) && (count.unreadmarked_msgs > 0))
     new_icon =
@@ -318,46 +317,43 @@ gboolean notification_trayicon_main_window_got_iconified(gpointer source,
 gboolean notification_trayicon_account_list_changed(gpointer source,
 						    gpointer data)
 {
-  GList *cur_ac, *cur_item = NULL;
-  GtkWidget *menu;
+  GList *cur_ac;
+	GtkWidget *menu, *submenu;
   GtkWidget *menuitem;
   PrefsAccount *ac_prefs;
-  
+
   GList *account_list = account_get_list();
 
   if(!notify_config.trayicon_enabled)
     return FALSE;
 
-  menu = gtk_item_factory_get_widget(traymenu_factory,
-				     "/Email from account");
+	menu = gtk_ui_manager_get_widget(gtkut_ui_manager(), "/Menus/SysTrayiconPopup/EmailAcc");
+	gtk_widget_show(menu);
 
-  /* destroy all previous menu item */
-  cur_item = GTK_MENU_SHELL(menu)->children;
-  while(cur_item != NULL) {
-    GList *next = cur_item->next;
-    gtk_widget_destroy(GTK_WIDGET(cur_item->data));
-    cur_item = next;
-  }
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu), NULL);
+	submenu = gtk_menu_new();
 
   for(cur_ac = account_list; cur_ac != NULL; cur_ac = cur_ac->next) {
     ac_prefs = (PrefsAccount *)cur_ac->data;
-    
+
     menuitem = gtk_menu_item_new_with_label
       (ac_prefs->account_name ? ac_prefs->account_name
        : _("Untitled"));
     gtk_widget_show(menuitem);
-    gtk_menu_append(GTK_MENU(menu), menuitem);
+		gtk_menu_shell_append(GTK_MENU_SHELL(submenu), menuitem);
     g_signal_connect(G_OBJECT(menuitem), "activate",
 		     G_CALLBACK(trayicon_compose_acc_cb),
 		     ac_prefs);
   }
+	gtk_widget_show(submenu);
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu), submenu);
   return FALSE;
 }
 
 static GdkPixbuf* notification_trayicon_create(void)
 {
   GdkPixbuf *trayicon_nomail;
-  gint n_entries = 0;
+	GtkActionGroup *action_group;
 
   trayicon_nomail = notification_pixbuf_get(NOTIFICATION_TRAYICON_NOMAIL);
 
@@ -365,7 +361,7 @@ static GdkPixbuf* notification_trayicon_create(void)
 
   trayicon = gtk_status_icon_new_from_pixbuf(trayicon_nomail);
 
-  g_signal_connect(G_OBJECT(trayicon), "activate", 
+  g_signal_connect(G_OBJECT(trayicon), "activate",
 		   G_CALLBACK(notification_trayicon_on_activate), NULL);
   g_signal_connect(G_OBJECT(trayicon), "popup-menu",
 		   G_CALLBACK(notification_trayicon_on_popup_menu), NULL);
@@ -373,11 +369,28 @@ static GdkPixbuf* notification_trayicon_create(void)
 		   G_CALLBACK(notification_trayicon_on_size_changed), NULL);
 
   /* Popup-Menu */
-  n_entries = sizeof(trayicon_popup_menu_entries) /
-    sizeof(trayicon_popup_menu_entries[0]);
-  traymenu_popup = menu_create_items(trayicon_popup_menu_entries,
-				     n_entries, "<TrayiconMenu>", &traymenu_factory,
-				     NULL);
+	action_group = cm_menu_create_action_group("SysTrayiconPopup", trayicon_popup_menu_entries,
+																						 G_N_ELEMENTS(trayicon_popup_menu_entries), NULL);
+	gtk_action_group_add_toggle_actions(action_group, trayicon_popup_toggle_menu_entries,
+																			G_N_ELEMENTS(trayicon_popup_toggle_menu_entries), NULL);
+
+	MENUITEM_ADDUI("/Menus", "SysTrayiconPopup", "SysTrayiconPopup", GTK_UI_MANAGER_MENU)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "GetMail", "SysTrayiconPopup/GetMail", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "Separator1", "SysTrayiconPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "Email", "SysTrayiconPopup/Email", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "EmailAcc", "SysTrayiconPopup/EmailAcc", GTK_UI_MANAGER_MENU)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "Separator2", "SysTrayiconPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "OpenAB", "SysTrayiconPopup/OpenAB", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "Separator3", "SysTrayiconPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "ToggleOffline", "SysTrayiconPopup/ToggleOffline", GTK_UI_MANAGER_MENUITEM)
+#ifdef HAVE_LIBNOTIFY
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "ShowBubbles", "SysTrayiconPopup/ShowBubbles", GTK_UI_MANAGER_MENUITEM)
+#endif
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "Separator4", "SysTrayiconPopup/---", GTK_UI_MANAGER_SEPARATOR)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "Exit", "SysTrayiconPopup/Exit", GTK_UI_MANAGER_MENUITEM)
+
+	traymenu_popup = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
+				gtk_ui_manager_get_widget(gtkut_ui_manager(), "/Menus/SysTrayiconPopup")));
 
   return trayicon_nomail;
 }
@@ -416,25 +429,22 @@ static void notification_trayicon_on_popup_menu(GtkStatusIcon *status_icon,
   /* tell callbacks to skip any event */
   updating_menu = TRUE;
   /* initialize checkitems according to current states */
-  gtk_check_menu_item_set_active
-    (GTK_CHECK_MENU_ITEM(gtk_item_factory_get_item
-			 (traymenu_factory, "/Work Offline")),
-     prefs_common.work_offline);
-
+	cm_toggle_menu_set_active("SysTrayiconPopup/ToggleOffline", prefs_common_get_prefs()->work_offline);
 #ifdef HAVE_LIBNOTIFY
-  gtk_check_menu_item_set_active
-    (GTK_CHECK_MENU_ITEM(gtk_item_factory_get_item
-			 (traymenu_factory, "/Show Trayicon Notifications")),
-     notify_config.trayicon_popup_enabled);
+	cm_toggle_menu_set_active("SysTrayiconPopup/ShowBubbles", notify_config.trayicon_popup_enabled);
 #endif
+	cm_menu_set_sensitive("SysTrayiconPopup/GetMail", mainwin->lock_count == 0);
 
-  gtk_widget_set_sensitive(GTK_WIDGET(gtk_item_factory_get_item(traymenu_factory,
-								"/Get Mail")),
-			   mainwin->lock_count == 0);
   updating_menu = FALSE;
 
+#ifndef G_OS_WIN32
   gtk_menu_popup(GTK_MENU(traymenu_popup), NULL, NULL, NULL, NULL,
 		 button, activate_time);
+#else
+  /* http://bugzilla.gnome.org/show_bug.cgi?id=552642 */
+  gtk_menu_popup(GTK_MENU(traymenu_popup), NULL, NULL, NULL, NULL,
+		 0, activate_time);
+#endif
 }
 
 static gboolean notification_trayicon_on_size_changed(GtkStatusIcon *icon,
@@ -442,46 +452,43 @@ static gboolean notification_trayicon_on_size_changed(GtkStatusIcon *icon,
 						      gpointer user_data)
 {
   notification_update_msg_counts(NULL);
-  return FALSE;  
+  return FALSE;
 }
 
 /* popup menu callbacks */
-static void trayicon_get_all_cb( gpointer data, guint action, GtkWidget *widget )
+static void trayicon_get_all_cb(GtkAction *action, gpointer data)
 {
   MainWindow *mainwin = mainwindow_get_mainwindow();
   inc_all_account_mail_cb(mainwin, 0, NULL);
 }
 
-static void trayicon_compose_cb( gpointer data, guint action, GtkWidget *widget )
+static void trayicon_compose_cb(GtkAction *action, gpointer data)
 {
   MainWindow *mainwin = mainwindow_get_mainwindow();
   compose_mail_cb(mainwin, 0, NULL);
 }
 
-static void trayicon_compose_acc_cb( GtkMenuItem *menuitem, gpointer data )
+static void trayicon_compose_acc_cb(GtkMenuItem *menuitem, gpointer data)
 {
   compose_new((PrefsAccount *)data, NULL, NULL);
 }
 
-static void trayicon_addressbook_cb(gpointer data, guint action,
-				    GtkWidget *widget)
+static void trayicon_addressbook_cb(GtkAction *action, gpointer data)
 {
   addressbook_open(NULL);
 }
 
-static void trayicon_toggle_offline_cb(gpointer data, guint action,
-				       GtkWidget *widget)
+static void trayicon_toggle_offline_cb(GtkAction *action, gpointer data)
 {
   /* toggle offline mode if menu checkitem has been clicked */
   if(!updating_menu) {
     MainWindow *mainwin = mainwindow_get_mainwindow();
-    main_window_toggle_work_offline(mainwin, !prefs_common.work_offline, TRUE);
+    main_window_toggle_work_offline(mainwin, !prefs_common_get_prefs()->work_offline, TRUE);
   }
 }
 
 #ifdef HAVE_LIBNOTIFY
-static void trayicon_toggle_notify_cb(gpointer data, guint action,
-				      GtkWidget *widget)
+static void trayicon_toggle_notify_cb(GtkAction *action, gpointer data)
 {
   if(!updating_menu) {
     notify_config.trayicon_popup_enabled = !notify_config.trayicon_popup_enabled;
@@ -491,7 +498,7 @@ static void trayicon_toggle_notify_cb(gpointer data, guint action,
 
 static void app_exit_cb(MainWindow *mainwin, guint action, GtkWidget *widget)
 {
-  if(prefs_common.confirm_on_exit) {
+  if(prefs_common_get_prefs()->confirm_on_exit) {
     if(alertpanel(_("Exit"), _("Exit Claws Mail?"),
 		  GTK_STOCK_CANCEL, GTK_STOCK_OK,
 		  NULL) != G_ALERTALTERNATE) {
@@ -499,14 +506,19 @@ static void app_exit_cb(MainWindow *mainwin, guint action, GtkWidget *widget)
     }
     manage_window_focus_in(mainwin->window, NULL, NULL);
   }
-  
+
+  if (prefs_common.clean_on_exit) {
+    if (!main_window_empty_trash(mainwin, prefs_common.ask_on_clean, TRUE))
+      return;
+  }
+
   app_will_exit(NULL, mainwin);
 }
 
-static void trayicon_exit_cb( gpointer data, guint action, GtkWidget *widget )
+static void trayicon_exit_cb(GtkAction *action, gpointer data)
 {
   MainWindow *mainwin = mainwindow_get_mainwindow();
-  
+
   if(mainwin->lock_count == 0) {
     app_exit_cb(mainwin, 0, NULL);
   }
@@ -542,7 +554,7 @@ static gboolean notification_trayicon_popup_add_msg(MsgInfo *msginfo,
   if(pixbuf)
     notify_notification_set_icon_from_pixbuf(popup.notification, pixbuf);
 
-  retval = notify_notification_update(popup.notification, summary, 
+  retval = notify_notification_update(popup.notification, summary,
 				      utf8_str, NULL);
   g_free(summary);
   g_free(utf8_str);
@@ -557,7 +569,7 @@ static gboolean notification_trayicon_popup_add_msg(MsgInfo *msginfo,
     g_clear_error(&(popup.error));
     return FALSE;
   }
-  
+
   debug_print("Notification Plugin: Popup successfully modified "
 	      "with libnotify.\n");
 
@@ -570,6 +582,8 @@ static gboolean notification_trayicon_popup_create(MsgInfo *msginfo,
   gchar *summary = NULL;
   gchar *utf8_str = NULL;
   GdkPixbuf *pixbuf;
+  GList *caps = NULL;
+  gboolean support_actions = FALSE;
 
   /* init libnotify if necessary */
   if(!notify_is_initted()) {
@@ -592,13 +606,28 @@ static gboolean notification_trayicon_popup_create(MsgInfo *msginfo,
   g_free(summary);
   g_free(utf8_str);
 
+  caps = notify_get_server_caps();
+    if(caps != NULL) {
+      GList *c;
+      for(c = caps; c != NULL; c = c->next) {
+	if(strcmp((char*)c->data, "actions") == 0 ) {
+	  support_actions = TRUE;
+	  break;
+        }
+      }
+
+    g_list_foreach(caps, (GFunc)g_free, NULL);
+    g_list_free(caps);
+  }
+
   /* Default action */
-  notify_notification_add_action(popup.notification,
-				 "default", "Present main window",
-				 (NotifyActionCallback)
-				 notification_trayicon_popup_default_action_cb,
-				 GINT_TO_POINTER(nftype),
-				 notification_trayicon_popup_free_func);
+  if (support_actions)
+    notify_notification_add_action(popup.notification,
+				   "default", "Present main window",
+				   (NotifyActionCallback)
+				   notification_trayicon_popup_default_action_cb,
+				   GINT_TO_POINTER(nftype),
+				   notification_trayicon_popup_free_func);
 
   if(popup.notification == NULL) {
     debug_print("Notification Plugin: Failed to create a new notification.\n");
@@ -627,7 +656,7 @@ static gboolean notification_trayicon_popup_create(MsgInfo *msginfo,
 	g_error_free(error);
       }
     }
-    else 
+    else
       debug_print("Picture path does not exist: %s\n",icon_path);
     g_free(icon_path);
   }
@@ -641,12 +670,15 @@ static gboolean notification_trayicon_popup_create(MsgInfo *msginfo,
   else /* This is not fatal */
     debug_print("Notification plugin: Icon could not be loaded.\n");
 
-  /* Never time out, close is handled manually. */
-  notify_notification_set_timeout(popup.notification, NOTIFY_EXPIRES_NEVER);
+  /* timeout */
+  notify_notification_set_timeout(popup.notification, notify_config.trayicon_popup_timeout);
 
   /* Category */
   notify_notification_set_category(popup.notification, "email.arrived");
 
+  /* get notified on bubble close */
+  g_signal_connect(G_OBJECT(popup.notification), "closed", G_CALLBACK(popup_timeout_fun), NULL);
+
   /* Show the popup */
   if(!notify_notification_show(popup.notification, &(popup.error))) {
     debug_print("Notification Plugin: Failed to send notification: %s\n",
@@ -675,24 +707,15 @@ static gboolean notification_trayicon_popup_create(MsgInfo *msginfo,
   return TRUE;
 }
 
-static gboolean popup_timeout_fun(gpointer data)
+static void popup_timeout_fun(NotifyNotification *nn, gpointer data)
 {
   G_LOCK(trayicon_popup);
 
-  if(!notify_notification_close(popup.notification, &(popup.error))) {
-    debug_print("Notification Plugin: Failed to close notification: %s.\n",
-		popup.error->message);
-    /* do I need to g_object_unref()? */
-  }
-  else {
-    g_object_unref(G_OBJECT(popup.notification));
-    debug_print("Notification Plugin: Popup closed due to timeout.\n");
-  }
+  g_object_unref(G_OBJECT(popup.notification));
+
   popup.notification = NULL;
   g_clear_error(&(popup.error));
 
-  popup.timeout_id = 0;
-
   popup.count = 0;
   popup.num_mail = 0;
   popup.num_news = 0;
@@ -705,8 +728,6 @@ static gboolean popup_timeout_fun(gpointer data)
   }
 
   G_UNLOCK(trayicon_popup);
-
-  return FALSE;
 }
 
 static void notification_trayicon_popup_free_func(gpointer data)
@@ -803,15 +824,15 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
       gchar *subj;
       gchar *text;
 	  gchar *foldname = NULL;
-      
-      from = notification_libnotify_sanitize_str(msginfo->from ? 
+
+      from = notification_libnotify_sanitize_str(msginfo->from ?
 						 msginfo->from :
 						 _("(No From)"));
       subj = notification_libnotify_sanitize_str(msginfo->subject ?
 						 msginfo->subject :
 						 _("(No Subject)"));
   	if (notify_config.trayicon_display_folder_name) {
-        foldname = notification_libnotify_sanitize_str(msginfo->folder->path); 
+        foldname = notification_libnotify_sanitize_str(msginfo->folder->path);
         text = g_strconcat(from,"\n\n", subj, "\n\n", foldname, NULL);
 	}
     else
