@@ -1,7 +1,7 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2004 Hiroyuki Yamamoto
- * This file (C) 2005 Andrej Kacian <andrej@kacian.sk>
+ * This file (C) 2005-2008 Andrej Kacian <andrej@kacian.sk> and the Claws Mail team
  *
  * - various feed parsing functions
  * - this file could use some sorting and/or splitting
@@ -34,6 +34,9 @@
 #include <libxml/xpath.h>
 #include <pthread.h>
 #include <time.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 
 #include "common/claws.h"
 #include "codeconv.h"
@@ -80,9 +83,14 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 	gchar *time_str = NULL;
 	long response_code;
 
+#ifndef G_OS_WIN32
 	gchar *template = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, RSSYL_DIR,
 			G_DIR_SEPARATOR_S, RSSYL_TMP_TEMPLATE, NULL);
 	int fd = mkstemp(template);
+#else
+	gchar *template = get_tmp_file();
+	int fd = open(template, (O_CREAT|O_RDWR|O_BINARY), (S_IRUSR|S_IWUSR));
+#endif
 	FILE *f;
 
 #ifdef USE_PTHREAD
@@ -126,10 +134,11 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 #if LIBCURL_VERSION_NUM < 0x071000
 	curl_easy_setopt(eh, CURLOPT_MUTE, 1);
 #endif
+	curl_easy_setopt(eh, CURLOPT_WRITEFUNCTION, NULL);
 	curl_easy_setopt(eh, CURLOPT_WRITEDATA, f);
 	curl_easy_setopt(eh, CURLOPT_FOLLOWLOCATION, 1);
 	curl_easy_setopt(eh, CURLOPT_MAXREDIRS, 3);
-	curl_easy_setopt(eh, CURLOPT_TIMEOUT, prefs_common.io_timeout_secs);
+	curl_easy_setopt(eh, CURLOPT_TIMEOUT, prefs_common_get_prefs()->io_timeout_secs);
 	curl_easy_setopt(eh, CURLOPT_NOSIGNAL, 1);
 #if LIBCURL_VERSION_NUM >= 0x070a00
 	curl_easy_setopt(eh, CURLOPT_SSL_VERIFYPEER, 0);
@@ -183,13 +192,13 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 			if( last_modified != -1 ) {
 				time_str = createRFC822Date(&last_modified);
 			}
-			debug_print("RSSyl: got status %d, last mod %ld (%s)\n",
+			debug_print("RSSyl: got status %ld, last mod %ld (%s)\n",
 					response_code, (long int) last_modified, 
 					(last_modified != -1 ? time_str : "unknown") );
 			g_free(time_str);
 			time_str = NULL;
 		} else {
-			debug_print("RSSyl: got status %d\n", response_code);
+			debug_print("RSSyl: got status %ld\n", response_code);
 		}
 	}
 
@@ -198,7 +207,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 	fclose(f);
 
 	if( response_code >= 400 && response_code < 500 ) {
-		debug_print("RSSyl: got %d\n", response_code);
+		debug_print("RSSyl: got %ld\n", response_code);
 		switch(response_code) {
 			case 401: 
 				ctx->error = g_strdup(_("401 (Authorisation required)"));
@@ -210,7 +219,7 @@ static void *rssyl_fetch_feed_threaded(void *arg)
 				ctx->error = g_strdup(_("404 (Not found)"));
 				break;
 			default:
-				ctx->error = g_strdup_printf(_("Error %d"), response_code);
+				ctx->error = g_strdup_printf(_("Error %ld"), response_code);
 				break;
 		}
 		ctx->ready = TRUE;
@@ -261,6 +270,7 @@ xmlDocPtr rssyl_fetch_feed(const gchar *url, time_t last_update, gchar **title,
 #endif
 	gchar *msg = NULL, *tmptitle = NULL;
 	gchar *content;
+	xmlErrorPtr xml_err;
 
 	ctx->url = url;
 	ctx->ready = FALSE;
@@ -317,13 +327,19 @@ xmlDocPtr rssyl_fetch_feed(const gchar *url, time_t last_update, gchar **title,
 	}
 		
 	/* Strip ugly \r\n endlines */
+#ifndef G_OS_WIN32
 	file_strip_crs((gchar *)template);
-
+#endif
+	debug_print("parsing %s\n", template);
 	doc = xmlParseFile(template);
-
+	
 	if( doc == NULL ) {
 		claws_unlink(template);
 		g_free(template);
+		xml_err = xmlGetLastError();
+		if (xml_err)
+			debug_print("error %s\n", xml_err->message);
+		
 		g_warning("Couldn't fetch feed '%s', aborting.\n", url);
 		log_error(LOG_PROTOCOL, RSSYL_LOG_ERROR_FETCH, url);
 		if (error && !(*error)) {
@@ -486,6 +502,12 @@ xmlDocPtr rssyl_fetch_feed(const gchar *url, time_t last_update, gchar **title,
 
 	g_return_val_if_fail(*title != NULL, NULL);
 
+	if (*title[0] == '\0') {
+		g_free(*title);
+		*title = g_strdup(url);
+		subst_for_shellsafe_filename(*title);
+	}
+
 	tmptitle = rssyl_strreplace(*title, "/", "\\");
 	dir = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, RSSYL_DIR,
 			G_DIR_SEPARATOR_S, tmptitle, NULL);
@@ -1048,11 +1070,6 @@ void rssyl_parse_feed(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 		count = rssyl_parse_rdf(doc, ritem, parent);
 	} else if( !strcmp(rootnode, "feed") ) {
 		debug_print("RSSyl: XML - calling rssyl_parse_atom()\n");
-		if (ritem->fetch_comments) {
-			log_error(LOG_PROTOCOL, _("RSSyl: Fetching comments is not supported for Atom feeds. "
-				    "Cannot fetch comments of '%s'"), ritem->item.name);
-			ritem->fetch_comments = FALSE;
-		}
 		count = rssyl_parse_atom(doc, ritem, parent);
 	} else {
 		alertpanel_error(_("This feed format is not supported yet."));
@@ -1111,9 +1128,14 @@ gboolean rssyl_add_feed_item(RSSylFolderItem *ritem, RSSylFeedItem *fitem)
 	ritem->contents = g_slist_append(ritem->contents, fitem);
 
 	flags = g_new(MsgFlags, 1);
+#ifndef G_OS_WIN32
 	template = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, RSSYL_DIR,
 			G_DIR_SEPARATOR_S, RSSYL_TMP_TEMPLATE, NULL);
 	fd = mkstemp(template);
+#else
+	template = get_tmp_file();
+	fd = open(template, (O_CREAT|O_RDWR|O_BINARY), (S_IRUSR|S_IWUSR));
+#endif
 
 	f = fdopen(fd, "w");
 	g_return_val_if_fail(f != NULL, FALSE);
@@ -1320,10 +1342,12 @@ void rssyl_update_comments(RSSylFolderItem *ritem)
 			if( (fitem = rssyl_parse_folder_item_file(d->d_name)) != NULL ) {
 				xmlDocPtr doc;
 				gchar *title;
-				if (fitem->comments_link) {
+				if (fitem->comments_link && fitem->id && 
+				    (ritem->fetch_comments_for == -1 ||
+				     time(NULL) - fitem->date <= ritem->fetch_comments_for*86400)) {
 					debug_print("RSSyl: fetching comments '%s'\n", fitem->comments_link);
 					doc = rssyl_fetch_feed(fitem->comments_link, ritem->item.mtime, &title, NULL);
-					rssyl_parse_feed(doc, ritem, fitem->link);
+					rssyl_parse_feed(doc, ritem, fitem->id);
 					xmlFreeDoc(doc);
 					g_free(title);
 				}
@@ -1527,6 +1551,7 @@ FolderItem *rssyl_subscribe_new_feed(FolderItem *parent, const gchar *url,
 		xmlFreeDoc(doc);
 		return NULL;
 	}
+
 	g_free(error);
 
 	new_item = folder_create_folder(parent, title);
@@ -1634,7 +1659,7 @@ void rssyl_refresh_all_func(FolderItem *item, gpointer data)
 
 void rssyl_refresh_all_feeds(void)
 {
-	if (prefs_common.work_offline && 
+	if (prefs_common_get_prefs()->work_offline && 
 	    !inc_offline_should_override(TRUE,
 			ngettext(
 			    "Claws Mail needs network access in order "
