@@ -28,7 +28,6 @@
 #include <glib.h>
 #include "gettext.h"
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 #include "common/claws.h"
 #include "common/version.h"
 #include "main.h"
@@ -67,7 +66,7 @@ static MimeInfo *tnef_broken_mimeinfo(const gchar *reason)
 			"%s\n"), reason?reason:_("Unknown error"));
 	
 	fclose(fp);
-	stat(tmpfilename, &statbuf);
+	g_stat(tmpfilename, &statbuf);
 	sub_info->tmp = TRUE;
 	sub_info->length = statbuf.st_size;
 	sub_info->encoding_type = ENC_BINARY;
@@ -116,7 +115,7 @@ static MimeInfo *tnef_dump_file(const gchar *filename, char *data, size_t size)
 		return tnef_broken_mimeinfo(_("Failed to write the part data."));
 	}
 	fclose(fp);
-	stat(tmpfilename, &statbuf);
+	g_stat(tmpfilename, &statbuf);
 	sub_info->tmp = TRUE;
 	sub_info->length = statbuf.st_size;
 	sub_info->encoding_type = ENC_BINARY;
@@ -147,7 +146,7 @@ MimeInfo *tnef_parse_vcal(TNEFStruct tnef)
 	result = SaveVCalendar(fp, tnef);
 	
 	fclose(fp);
-	stat(tmpfilename, &statbuf);
+	g_stat(tmpfilename, &statbuf);
 	sub_info->tmp = TRUE;
 	sub_info->length = statbuf.st_size;
 	sub_info->encoding_type = ENC_BINARY;
@@ -183,7 +182,7 @@ MimeInfo *tnef_parse_vtask(TNEFStruct tnef)
 	result = SaveVTask(fp, tnef);
 	
 	fclose(fp);
-	stat(tmpfilename, &statbuf);
+	g_stat(tmpfilename, &statbuf);
 	sub_info->tmp = TRUE;
 	sub_info->length = statbuf.st_size;
 	sub_info->encoding_type = ENC_BINARY;
@@ -233,7 +232,7 @@ MimeInfo *tnef_parse_vcard(TNEFStruct tnef)
 	result = SaveVCard(fp, tnef);
 	
 	fclose(fp);
-	stat(tmpfilename, &statbuf);
+	g_stat(tmpfilename, &statbuf);
 	sub_info->tmp = TRUE;
 	sub_info->length = statbuf.st_size;
 	sub_info->encoding_type = ENC_BINARY;
@@ -366,6 +365,8 @@ static gboolean tnef_parse (MimeParser *parser, MimeInfo *mimeinfo)
 		sub_info = NULL;
 		
 		att = att->next;
+
+		g_free(filename);
 	}
 	
 	TNEFFree(&tnef);
@@ -374,7 +375,11 @@ static gboolean tnef_parse (MimeParser *parser, MimeInfo *mimeinfo)
 
 gint plugin_init(gchar **error)
 {
+#ifdef G_OS_UNIX
 	bindtextdomain(TEXTDOMAIN, LOCALEDIR);
+#else
+	bindtextdomain(TEXTDOMAIN, get_locale_dir());
+#endif
 	bind_textdomain_codeset(TEXTDOMAIN, "UTF-8");
 
 	if (!check_plugin_version(MAKE_NUMERIC_VERSION(2,9,2,72),
