@@ -2,7 +2,7 @@
 #define ICAL_VERSION_H
 
 #define ICAL_PACKAGE "vcalendar"
-#define ICAL_VERSION "2.0"
+#define ICAL_VERSION "2.0.5"
 
 #endif
 /* -*- Mode: C -*- */
@@ -11,7 +11,7 @@
  CREATOR: eric 02 June 2000
 
 
- $Id: icaltime.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+ $Id: icaltime.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
  $Locker:  $
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -156,7 +156,7 @@ short icaltime_days_in_month(short month,short year);
  CREATOR: eric 26 Jan 2001
 
 
- $Id: icalduration.h,v 1.1.2.1 2005/07/04 17:06:56 colinleroy Exp $
+ $Id: icalduration.h,v 1.1.2.1 2005-07-04 17:06:56 colinleroy Exp $
  $Locker:  $
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -215,7 +215,7 @@ struct icaldurationtype  icaltime_subtract(struct icaltimetype t1,
  CREATOR: eric 26 Jan 2001
 
 
- $Id: icalperiod.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+ $Id: icalperiod.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
  $Locker:  $
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -745,7 +745,7 @@ int icalrecur_expand_recurrence(char* rule, time_t start,
   CREATOR: eric 20 March 1999
 
 
-  $Id: icalderivedvalue.h.in,v 1.1.2.1 2005/07/04 17:06:56 colinleroy Exp $
+  $Id: icalderivedvalue.h.in,v 1.1.2.1 2005-07-04 17:06:56 colinleroy Exp $
   $Locker:  $
 
   
@@ -1030,7 +1030,7 @@ void icalvalue_set_method(icalvalue* value, enum icalproperty_method v);
   CREATOR: eric 20 March 1999
 
 
-  $Id: icalderivedparameter.h.in,v 1.1.2.1 2005/07/04 17:06:56 colinleroy Exp $
+  $Id: icalderivedparameter.h.in,v 1.1.2.1 2005-07-04 17:06:56 colinleroy Exp $
   $Locker:  $
 
   
@@ -1344,7 +1344,7 @@ void icalparameter_set_role(icalparameter* value, icalparameter_role v);
   CREATOR: eric 20 March 1999
 
 
-  $Id: icalvalue.h,v 1.1.2.1 2005/07/04 17:06:58 colinleroy Exp $
+  $Id: icalvalue.h,v 1.1.2.1 2005-07-04 17:06:58 colinleroy Exp $
   $Locker:  $
 
   
@@ -1421,7 +1421,7 @@ const char* icalvalue_kind_to_string(icalvalue_kind kind);
   CREATOR: eric 20 March 1999
 
 
-  $Id: icalparameter.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+  $Id: icalparameter.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
   $Locker:  $
 
   
@@ -1488,7 +1488,7 @@ icalparameter_kind icalparameter_string_to_kind(const char* string);
   FILE: icalderivedproperties.{c,h}
   CREATOR: eric 09 May 1999
   
-  $Id: icalderivedproperty.h.in,v 1.1.2.1 2005/07/04 17:06:56 colinleroy Exp $
+  $Id: icalderivedproperty.h.in,v 1.1.2.1 2005-07-04 17:06:56 colinleroy Exp $
     
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
  ======================================================================*/
@@ -1889,7 +1889,7 @@ const char* icalproperty_get_xlicmimeoptinfo(icalproperty* prop);
   CREATOR: eric 20 March 1999
 
 
-  $Id: icalproperty.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+  $Id: icalproperty.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
   $Locker:  $
 
   
@@ -2391,7 +2391,7 @@ icalcomponent* icalcomponent_new_xdaylight();
   FILE: icalparser.h
   CREATOR: eric 20 April 1999
   
-  $Id: icalparser.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+  $Id: icalparser.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
 
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -2482,7 +2482,7 @@ char* string_line_generator(char *out, size_t buf_size, void *d);
  CREATOR: eric 30 June 1999
 
 
- $Id: icalmemory.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+ $Id: icalmemory.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
  $Locker:  $
 
  This program is free software; you can redistribute it and/or modify
@@ -2561,7 +2561,7 @@ char* icalmemory_strdup(const char *s);
   FILE: icalerror.h
   CREATOR: eric 09 May 1999
   
-  $Id: icalerror.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+  $Id: icalerror.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
 
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -2714,7 +2714,7 @@ void icalerror_restore(const char* error, icalerrorstate es);
   FILE: icalrestriction.h
   CREATOR: eric 24 April 1999
   
-  $Id: icalrestriction.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+  $Id: icalrestriction.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
 
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -2775,7 +2775,7 @@ int icalrestriction_check(icalcomponent* comp);
   FILE: sspm.h Mime Parser
   CREATOR: eric 25 June 2000
   
-  $Id: sspm.h,v 1.1.2.1 2005/07/04 17:06:58 colinleroy Exp $
+  $Id: sspm.h,v 1.1.2.1 2005-07-04 17:06:58 colinleroy Exp $
   $Locker:  $
     
  The contents of this file are subject to the Mozilla Public License
@@ -2919,7 +2919,7 @@ int sspm_write_mime(struct sspm_part *parts,size_t num_parts,
  CREATOR: eric 26 July 2000
 
 
- $Id: icalmime.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+ $Id: icalmime.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
  $Locker:  $
 
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
@@ -2961,7 +2961,7 @@ char* icalmime_as_mime_string(char* component);
   
   DESCRIPTION:
   
-  $Id: icallangbind.h,v 1.1.2.1 2005/07/04 17:06:57 colinleroy Exp $
+  $Id: icallangbind.h,v 1.1.2.1 2005-07-04 17:06:57 colinleroy Exp $
   $Locker:  $
 
   (C) COPYRIGHT 1999 Eric Busboom 
