@@ -46,8 +46,9 @@
 struct _month_win
 {
     GtkAccelGroup *accel_group;
+#if !GTK_CHECK_VERSION(2,12,0)
     GtkTooltips   *Tooltips;
-
+#endif
     GtkWidget *Window;
     GtkWidget *Vbox;
 
@@ -94,9 +95,9 @@ struct _month_win
     FolderItem *item;
     gulong selsig;
     GtkWidget *view_menu;
-    GtkItemFactory *view_fact;
     GtkWidget *event_menu;
-    GtkItemFactory *event_fact;
+    GtkActionGroup *event_group;
+    GtkUIManager *ui_manager;
 };
 
 gchar *dayname[7] = {
@@ -134,7 +135,9 @@ void mw_close_window(month_win *mw)
 {
     vcal_view_set_summary_page(mw->Vbox, mw->selsig);
     
-    gtk_object_destroy(GTK_OBJECT(mw->Tooltips));
+#if !(GTK_CHECK_VERSION(2,12,0))
+    gtk_object_destroy(G_OBJECT(mw->Tooltips));
+#endif
     g_free(mw);
     mw = NULL;
 }
@@ -184,10 +187,10 @@ static gint on_Next_clicked(GtkWidget *button, GdkEventButton *event,
     return TRUE;
 }
 
-static void mw_summary_selected(GtkCTree *ctree, GtkCTreeNode *row,
+static void mw_summary_selected(GtkCMCTree *ctree, GtkCMCTreeNode *row,
 			     gint column, month_win *mw)
 {
-	MsgInfo *msginfo = gtk_ctree_node_get_row_data(ctree, row);
+	MsgInfo *msginfo = gtk_cmctree_node_get_row_data(ctree, row);
 	
 	if (msginfo && msginfo->msgid) {
 		VCalEvent *event = vcal_manager_load_event(msginfo->msgid);
@@ -196,6 +199,10 @@ static void mw_summary_selected(GtkCTree *ctree, GtkCTreeNode *row,
 			time_t t_start = icaltime_as_timet(icaltime_from_string(event->dtstart));
 			gboolean changed = FALSE;
 
+#ifdef G_OS_WIN32
+			if (t_start < 0)
+				t_start = 1;
+#endif
 			localtime_r(&t_start, &tm_start);
 			while (tm_start.tm_year < mw->startdate.tm_year) {
 				changeSelectedDate(mw, -1);
@@ -337,6 +344,9 @@ static void add_row(month_win *mw, VCalEvent *event, gint days)
     gboolean pack = TRUE, update_tip = FALSE;
     time_t now = time(NULL);
     struct tm tm_today;
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = mw->Tooltips;
+#endif
 
     localtime_r(&now, &tm_today);
 
@@ -350,6 +360,12 @@ static void add_row(month_win *mw, VCalEvent *event, gint days)
     else 
 	t_end = t_start;
 
+#ifdef G_OS_WIN32
+	if (t_start < 0)
+		t_start = 1;
+	if (t_end < 0)
+		t_end = 1;
+#endif
     localtime_r(&t_start, &tm_start);
     localtime_r(&t_end, &tm_end);
     tm_first = mw->startdate;
@@ -424,6 +440,8 @@ static void add_row(month_win *mw, VCalEvent *event, gint days)
        gtk_label_set_ellipsize(GTK_LABEL(lab), PANGO_ELLIPSIZE_END);
        if ((row % 2) == 1)
            gtk_widget_modify_bg(ev, GTK_STATE_NORMAL, &mw->bg1);
+       else
+           gtk_widget_modify_bg(ev, GTK_STATE_NORMAL, &mw->bg2);
     } else if (!pack && update_tip) {
        GList *children = gtk_container_get_children(GTK_CONTAINER(hb));
        ev = GTK_WIDGET(g_list_last(children)->data);
@@ -452,17 +470,23 @@ static void add_row(month_win *mw, VCalEvent *event, gint days)
     }
     if (pack) {
         gtk_container_add(GTK_CONTAINER(ev), lab);
-	gtk_tooltips_set_tip(mw->Tooltips, ev, tip, NULL);
+	CLAWS_SET_TIP(ev, tip);
         gtk_box_pack_start(GTK_BOX(hb), ev, TRUE, TRUE, 0);
     } else if (!update_tip) {
         gtk_label_set_label(GTK_LABEL(lab), "...");
         gtk_container_add(GTK_CONTAINER(ev), lab);
-	gtk_tooltips_set_tip(mw->Tooltips, ev, tip, NULL);
+	CLAWS_SET_TIP(ev, tip);
         gtk_box_pack_start(GTK_BOX(hb), ev, TRUE, TRUE, 0);
     } else {
+#if !GTK_CHECK_VERSION(2,12,0)
         GtkTooltipsData *tdata = gtk_tooltips_data_get(ev);
 	gchar *new = g_strdup_printf("%s\n\n%s", tdata?tdata->tip_text:"", tip);
-	gtk_tooltips_set_tip(mw->Tooltips, ev, new, NULL);
+#else
+	gchar *old = gtk_widget_get_tooltip_text(ev);
+	gchar *new = g_strdup_printf("%s\n\n%s", old?old:"", tip);
+	g_free(old);
+#endif
+	CLAWS_SET_TIP(ev, new);
 	g_free(new);
     }
     g_object_set_data_full(G_OBJECT(ev), "UID", g_strdup(event->uid), g_free);
@@ -543,7 +567,10 @@ static void fill_days(month_win *mw, gint days, FolderItem *item)
     int weekoffset = -1;
     time_t now = time(NULL);
     struct tm tm_today;
-    
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = mw->Tooltips;
+#endif
+
     
     localtime_r(&now, &tm_today);
 
@@ -618,13 +645,16 @@ static void fill_days(month_win *mw, gint days, FolderItem *item)
         	    , G_CALLBACK(header_button_clicked_cb), mw);
             name = gtk_label_new(label);
 	    gtk_misc_set_alignment(GTK_MISC(name), 0.0, 0.0);
-	    gtk_tooltips_set_tip(mw->Tooltips, ev, tmp, NULL);
+
+	    CLAWS_SET_TIP(ev, tmp);
             gtk_container_add(GTK_CONTAINER(ev), name);
 	    g_free(tmp);
             g_free(label);
 
             if ((row % 2) == 1)
                 gtk_widget_modify_bg(ev, GTK_STATE_NORMAL, &mw->bg1);
+            else
+                gtk_widget_modify_bg(ev, GTK_STATE_NORMAL, &mw->bg2);
 	    if (col == 7)
 	    	gtk_widget_modify_fg(name, GTK_STATE_NORMAL, &mw->fg_sunday);
 	    if (day == tm_today.tm_mday && t.tm_mon == tm_today.tm_mon && t.tm_year == tm_today.tm_year)
@@ -691,19 +721,29 @@ static void build_month_view_colours(month_win *mw)
 {
     GtkStyle *def_style;
     GdkColormap *pic1_cmap;
-
+    GtkWidget *ctree = NULL;
     def_style = gtk_widget_get_default_style();
     pic1_cmap = gdk_colormap_get_system();
-    mw->bg1 = def_style->bg[GTK_STATE_NORMAL];
-    mw->bg1.red +=  (mw->bg1.red < 64000 ? 1000 : -1000);
-    mw->bg1.green += (mw->bg1.green < 64000 ? 1000 : -1000);
-    mw->bg1.blue += (mw->bg1.blue < 64000 ? 1000 : -1000);
+    
+    if (mainwindow_get_mainwindow()) {
+        ctree = mainwindow_get_mainwindow()->summaryview->ctree;
+    }
+    if (ctree) {
+        mw->bg1 = ctree->style->bg[GTK_STATE_NORMAL];
+        mw->bg2 = ctree->style->bg[GTK_STATE_NORMAL];
+    } else {
+        mw->bg1 = def_style->bg[GTK_STATE_NORMAL];
+        mw->bg2 = def_style->bg[GTK_STATE_NORMAL];
+    }
+
+    mw->bg1.red +=  (mw->bg1.red < 63000 ? 2000 : -2000);
+    mw->bg1.green += (mw->bg1.green < 63000 ? 2000 : -2000);
+    mw->bg1.blue += (mw->bg1.blue < 63000 ? 2000 : -2000);
     gdk_colormap_alloc_color(pic1_cmap, &mw->bg1, FALSE, TRUE);
 
-    mw->bg2 = def_style->bg[GTK_STATE_NORMAL];
     mw->bg2.red +=  (mw->bg2.red > 1000 ? -1000 : 1000);
     mw->bg2.green += (mw->bg2.green > 1000 ? -1000 : 1000);
-    mw->bg2.blue += (mw->bg2.blue > 2000 ? -2000 : 2000);
+    mw->bg2.blue += (mw->bg2.blue > 1000 ? -1000 : 1000);
     gdk_colormap_alloc_color(pic1_cmap, &mw->bg2, FALSE, TRUE);
 
     if (!gdk_color_parse("white", &mw->line_color)) {
@@ -711,7 +751,6 @@ static void build_month_view_colours(month_win *mw)
         mw->line_color.green = 235 * (65535/255);
         mw->line_color.blue = 230 * (65535/255);
     }
-    gdk_colormap_alloc_color(pic1_cmap, &mw->line_color, FALSE, TRUE);
 
     if (!gdk_color_parse("blue", &mw->fg_sunday)) {
         g_warning("color parse failed: red\n");
@@ -719,7 +758,6 @@ static void build_month_view_colours(month_win *mw)
         mw->fg_sunday.green = 10 * (65535/255);
         mw->fg_sunday.blue = 255 * (65535/255);
     }
-    gdk_colormap_alloc_color(pic1_cmap, &mw->fg_sunday, FALSE, TRUE);
 
     if (!gdk_color_parse("gold", &mw->bg_today)) {
         g_warning("color parse failed: gold\n");
@@ -727,17 +765,31 @@ static void build_month_view_colours(month_win *mw)
         mw->bg_today.green = 215 * (65535/255);
         mw->bg_today.blue = 115 * (65535/255);
     }
+
+    if (ctree) {
+        mw->fg_sunday.red = (mw->fg_sunday.red + ctree->style->fg[GTK_STATE_SELECTED].red)/2;
+        mw->fg_sunday.green = (mw->fg_sunday.green + ctree->style->fg[GTK_STATE_SELECTED].red)/2;
+        mw->fg_sunday.blue = (3*mw->fg_sunday.blue + ctree->style->fg[GTK_STATE_SELECTED].red)/4;
+        mw->bg_today.red = (3*mw->bg_today.red + ctree->style->bg[GTK_STATE_NORMAL].red)/4;
+        mw->bg_today.green = (3*mw->bg_today.green + ctree->style->bg[GTK_STATE_NORMAL].red)/4;
+        mw->bg_today.blue = (3*mw->bg_today.blue + ctree->style->bg[GTK_STATE_NORMAL].red)/4;
+    }
+    gdk_colormap_alloc_color(pic1_cmap, &mw->line_color, FALSE, TRUE);
+    gdk_colormap_alloc_color(pic1_cmap, &mw->fg_sunday, FALSE, TRUE);
     gdk_colormap_alloc_color(pic1_cmap, &mw->bg_today, FALSE, TRUE);
 }
 
 static void fill_hour(month_win *mw, gint col, gint row, char *text)
 {
     GtkWidget *name, *ev;
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = mw->Tooltips;
+#endif
 
     ev = gtk_event_box_new();
     name = gtk_label_new(text);
     gtk_misc_set_alignment(GTK_MISC(name), 0, 0.5);
-    gtk_tooltips_set_tip(mw->Tooltips, ev, _("Week number"), NULL);
+    CLAWS_SET_TIP(ev, _("Week number"));
     gtk_container_add(GTK_CONTAINER(ev), name);
     gtk_widget_set_size_request(ev, mw->hour_req.width
             , mw->StartDate_button_req.height);
@@ -765,6 +817,9 @@ static void build_month_view_table(month_win *mw)
     int weekoffset = -1;
     GDate *date;
     int first_week=0;
+#if !(GTK_CHECK_VERSION(2,12,0))
+	GtkTooltips *tips = mw->Tooltips;
+#endif
 
     if (mainwindow_get_mainwindow()) {
         GtkAllocation allocation;
@@ -787,6 +842,10 @@ static void build_month_view_table(month_win *mw)
     if (avail_d)
         gtk_spin_button_set_value(GTK_SPIN_BUTTON(mw->day_spin), avail_d);
 
+#ifdef G_OS_WIN32
+	if (t < 0)
+		t = 1;
+#endif
     localtime_r(&t, &tm_today);
     days = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(mw->day_spin));
     /****** header of day table = days columns ******/
@@ -828,12 +887,12 @@ static void build_month_view_table(month_win *mw)
     gtk_widget_show_all(mw->Previous_toolbutton);
     g_signal_connect((gpointer)mw->Previous_toolbutton, "button_release_event"
             , G_CALLBACK(on_Previous_clicked), mw);
-    gtk_tooltips_set_tip(mw->Tooltips, mw->Previous_toolbutton, _("Previous month"), NULL);
+    CLAWS_SET_TIP(mw->Previous_toolbutton, _("Previous month"));
     for (i = 1; i < days+1; i++) {
         button = gtk_label_new(_(dayname[i-1]));
 
         if (i == 8) {
-            gtk_widget_modify_fg(label, GTK_STATE_NORMAL, &mw->fg_sunday);
+            gtk_widget_modify_fg(button, GTK_STATE_NORMAL, &mw->fg_sunday);
         }
         gtk_widget_set_size_request(button, mw->StartDate_button_req.width, -1);
         g_object_set_data(G_OBJECT(button), "offset", GINT_TO_POINTER(i-1));
@@ -851,7 +910,7 @@ static void build_month_view_table(month_win *mw)
     gtk_widget_show_all(mw->Next_toolbutton);
     g_signal_connect((gpointer)mw->Next_toolbutton, "button_release_event"
             , G_CALLBACK(on_Next_clicked), mw);
-    gtk_tooltips_set_tip(mw->Tooltips, mw->Next_toolbutton, _("Next month"), NULL);
+    CLAWS_SET_TIP(mw->Next_toolbutton, _("Next month"));
 
     /****** body of day table ******/
     mw->scroll_win = gtk_scrolled_window_new(NULL, NULL);
@@ -913,11 +972,14 @@ month_win *create_month_win(FolderItem *item, struct tm tmdate)
 {
     month_win *mw;
     char *start_date = get_locale_date(&tmdate);
-    
+    CLAWS_TIP_DECL();
+
     /* initialisation + main window + base vbox */
     mw = g_new0(month_win, 1);
     mw->scroll_pos = -1; /* not set */
-    mw->Tooltips = gtk_tooltips_new();
+#if !(GTK_CHECK_VERSION(2,12,0))
+    mw->Tooltips = tips;
+#endif
     mw->accel_group = gtk_accel_group_new();
 
     while (tmdate.tm_mday != 1)
@@ -935,7 +997,8 @@ month_win *create_month_win(FolderItem *item, struct tm tmdate)
     mw->selsig = vcal_view_set_calendar_page(mw->Vbox, 
 		    G_CALLBACK(mw_summary_selected), mw);
 
-    vcal_view_create_popup_menus(mw->Vbox, &mw->view_menu, &mw->view_fact,
-		    		 &mw->event_menu, &mw->event_fact);
+    vcal_view_create_popup_menus(mw->Vbox, &mw->view_menu,
+		    		 &mw->event_menu, &mw->event_group,
+		    		 &mw->ui_manager);
     return(mw);
 }
