@@ -247,6 +247,7 @@ void vcal_manager_event_print(VCalEvent *event)
 		"event->organizer\t\t%s\n"
 		"event->start\t\t%s\n"
 		"event->end\t\t%s\n"
+		"event->location\t\t%s\n"
 		"event->summary\t\t%s\n"
 		"event->description\t%s\n"
 		"event->url\t%s\n"
@@ -260,6 +261,7 @@ void vcal_manager_event_print(VCalEvent *event)
 		event->organizer,
 		event->start,
 		event->end,
+		event->location,
 		event->summary,
 		event->description,
 		event->url,
@@ -395,8 +397,12 @@ gchar *vcal_manager_event_dump(VCalEvent *event, gboolean is_reply, gboolean is_
 		icalproperty_new_class("PUBLIC"));
 	icalcomponent_add_property(ievent,
 		icalproperty_new_transp("OPAQUE"));
-	icalcomponent_add_property(ievent,
-		icalproperty_new_location(""));
+	if (event->location && *event->location)
+		icalcomponent_add_property(ievent,
+			icalproperty_new_location(event->location));
+	else
+		icalcomponent_add_property(ievent,
+			icalproperty_new_location(""));
 	icalcomponent_add_property(ievent,
 		icalproperty_new_status(ICAL_STATUS_CONFIRMED));
 	icalcomponent_add_property(ievent,
@@ -504,7 +510,13 @@ static void get_rfc822_date_from_time_t(gchar *buf, gint len, time_t t)
 	gchar buft1[512];
 	struct tm buft2;
 
+#ifndef G_OS_WIN32
 	lt = localtime_r(&t, &buft2);
+#else
+	if (t < 0)
+		t = 1;
+	lt = localtime(&t);
+#endif
 
 	sscanf(asctime_r(lt, buft1), "%3s %3s %d %d:%d:%d %d\n",
 	       day, mon, &dd, &hh, &mm, &ss, &yyyy);
@@ -544,12 +556,16 @@ static gchar *write_headers_date(const gchar *uid)
 		return NULL;
 	} 
 	
+#ifndef G_OS_WIN32
 	lt = *localtime_r(&t, &buft);
+#else
+	if (t < 0)
+		t = 1;
+	lt = *localtime(&t);
+#endif
 	lt.tm_hour = lt.tm_min = lt.tm_sec = 0;
 	t = mktime(&lt);
-
 	get_rfc822_date_from_time_t(date, sizeof(date), t);
-
 	conv_encode_header(subject, 511, t_subject, strlen("Subject: "), FALSE);
 				
 	return g_strdup_printf("From: -\n"
@@ -567,11 +583,11 @@ static gchar *write_headers_date(const gchar *uid)
 
 gchar *vcal_manager_dateevent_dump(const gchar *uid, FolderItem *item)
 {
-	gchar *sanitized_uid = g_strdup(uid);
+	gchar *sanitized_uid = NULL;
 	gchar *headers = NULL;
 	gchar *lines, *body, *tmpfile;
 	EventTime date;
-	
+	sanitized_uid = g_strdup(uid);
 	subst_for_filename(sanitized_uid);
 	
 	tmpfile = g_strdup_printf("%s%cevt-%d-%s", get_tmp_dir(),
@@ -622,7 +638,7 @@ static gchar *write_headers_ical(PrefsAccount 	*account,
 
 gchar *vcal_manager_icalevent_dump(icalcomponent *event, gchar *orga, icalcomponent *use_calendar)
 {
-	PrefsAccount *account = cur_account;
+	PrefsAccount *account = account_get_cur_account();
 	gchar *body, *headers, *qpbody;
 	gchar **lines = NULL;
 	gchar *tmpfile = NULL;
@@ -735,6 +751,7 @@ gchar *vcal_manager_icalevent_dump(icalcomponent *event, gchar *orga, icalcompon
 VCalEvent * vcal_manager_new_event	(const gchar 	*uid, 
 					 const gchar	*organizer,
 					 const gchar	*orgname,
+					 const gchar	*location,
 					 const gchar	*summary,
 					 const gchar	*description,
 					 const gchar	*dtstart,
@@ -768,6 +785,7 @@ VCalEvent * vcal_manager_new_event	(const gchar 	*uid,
 	event->dtstart		= g_strdup(dtstart?dtstart:"");
 	event->dtend		= g_strdup(dtend?dtend:"");
 	event->recur		= g_strdup(recur?recur:"");
+	event->location 	= g_strdup(location?location:"");
 	event->summary		= g_strdup(summary?summary:"");
 	event->description	= g_strdup(description?description:"");
 	event->url		= g_strdup(url?url:"");
@@ -793,6 +811,7 @@ void vcal_manager_free_event (VCalEvent *event)
 	g_free(event->orgname);
 	g_free(event->start);
 	g_free(event->end);
+	g_free(event->location);
 	g_free(event->summary);
 	g_free(event->dtstart);
 	g_free(event->dtend);
@@ -861,6 +880,7 @@ void vcal_manager_save_event (VCalEvent *event, gboolean export_after)
 	tag = xml_tag_new("event");
 	xml_tag_add_attr(tag, xml_attr_new("organizer", event->organizer));
 	xml_tag_add_attr(tag, xml_attr_new("orgname", event->orgname));
+	xml_tag_add_attr(tag, xml_attr_new("location", event->location));
 	xml_tag_add_attr(tag, xml_attr_new("summary", event->summary));
 	xml_tag_add_attr(tag, xml_attr_new("description", event->description));
 	xml_tag_add_attr(tag, xml_attr_new("url", event->url));
@@ -943,7 +963,7 @@ static VCalEvent *event_get_from_xml (const gchar *uid, GNode *node)
 {
 	XMLNode *xmlnode;
 	GList *list;
-	gchar *org = NULL, *summary = NULL, *orgname = NULL;
+	gchar *org = NULL, *location = NULL, *summary = NULL, *orgname = NULL;
 	gchar *dtstart = NULL, *dtend = NULL, *tzid = NULL;
 	gchar *description = NULL, *url = NULL, *recur = NULL;
 	VCalEvent *event = NULL;
@@ -969,6 +989,8 @@ static VCalEvent *event_get_from_xml (const gchar *uid, GNode *node)
 			org = g_strdup(attr->value);
 		if (!strcmp(attr->name, "orgname"))
 			orgname = g_strdup(attr->value);
+		if (!strcmp(attr->name, "location"))
+			location = g_strdup(attr->value);
 		if (!strcmp(attr->name, "summary"))
 			summary = g_strdup(attr->value);
 		if (!strcmp(attr->name, "description"))
@@ -995,7 +1017,7 @@ static VCalEvent *event_get_from_xml (const gchar *uid, GNode *node)
 			rec_occurence = atoi(attr->value);
 	}
 
-	event = vcal_manager_new_event(uid, org, orgname, summary, description, 
+	event = vcal_manager_new_event(uid, org, orgname, location, summary, description, 
 					dtstart, dtend, recur, tzid, url, method, 
 					sequence, type);
 
@@ -1004,6 +1026,7 @@ static VCalEvent *event_get_from_xml (const gchar *uid, GNode *node)
 
 	g_free(org); 
 	g_free(orgname); 
+	g_free(location);
 	g_free(summary); 
 	g_free(description); 
 	g_free(url); 
@@ -1227,7 +1250,7 @@ static gchar *write_headers(PrefsAccount 	*account,
 		g_snprintf(msgid, sizeof(msgid), "%s", "");
 	}
 
-	generate_msgid(msgid, sizeof(msgid));
+	generate_msgid(msgid, sizeof(msgid), account->address);
 
 	result = g_strdup_printf("%s"
 				"From: %s <%s>\n"
@@ -1372,7 +1395,7 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 	folderitem = account_get_special_folder(account, F_QUEUE);
 	if (!folderitem) {
 		g_warning("can't find queue folder for %s\n", account->address);
-		unlink(tmpfile);
+		g_unlink(tmpfile);
 		g_free(tmpfile);
 		return FALSE;
 	}
@@ -1380,14 +1403,14 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 	
 	if ((msgnum = folder_item_add_msg(folderitem, tmpfile, NULL, TRUE)) < 0) {
 		g_warning("can't queue the message\n");
-		unlink(tmpfile);
+		g_unlink(tmpfile);
 		g_free(tmpfile);
 		return FALSE;
 	}
 
 	msgpath = folder_item_fetch_msg(folderitem, msgnum);
 	
-	if (!prefs_common.work_offline) {
+	if (!prefs_common_get_prefs()->work_offline) {
 		gchar *err = NULL;
 		gboolean queued_removed = FALSE;
 		gint val = procmsg_send_message_queue(msgpath, &err, folderitem, msgnum, &queued_removed);
@@ -1400,7 +1423,7 @@ static gboolean vcal_manager_send (PrefsAccount 	*account,
 			g_free(err);
 		}
 	}
-	unlink(tmpfile);
+	g_unlink(tmpfile);
 	g_free(tmpfile);
 	g_free(msgpath);
 
@@ -1441,8 +1464,17 @@ EventTime event_to_today(VCalEvent *event, time_t t)
 		evtstart_t = t;
 	}
 	
+#ifndef G_OS_WIN32
 	today = *localtime_r(&today_t, &buft);
 	localtime_r(&evtstart_t, &evtstart);
+#else
+	if (today_t < 0)
+		today_t = 1;
+	if (evtstart_t < 0)
+		evtstart_t = 1;
+	today = *localtime(&today_t);
+	evtstart = *localtime(&evtstart_t);
+#endif
 	
 	if (today.tm_year == evtstart.tm_year) {
 		int days = evtstart.tm_yday - today.tm_yday;
